import allure

from service.app_a.asserts.common.asserts_common_user4c import AssertsCommonUser4C
from service.app_a.apis.common import apis_common_user4c


class FunsCommonUser4C(AssertsCommonUser4C):
    @allure.step(title="用户列表-活动来源-Y")
    def common_user4c_queryactivitysource(self, _assert=True,  **kwargs):
        """
            url=/common/user4C/queryActivitySource
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_queryactivitysource(**_kwargs)

        self.assert_common_user4c_queryactivitysource(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户列表-查询-Y")
    def common_user4c_page(self, userId="$None$", lastLoginTimeEnd="$None$", size=10, createTimeStart="$None$", nickName="$None$", memberSystemSource="$None$", userSystemSource="$None$", createTimeEnd="$None$", regisTimeEnd="$None$", lastLoginTimeStart="$None$", mobile="$None$", ownerFlag="$None$", regisTimeBegin="$None$", activitySource="$None$", status="$None$", current=1, type="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/page
                params: mobile :  : 用户手机号码
                params: nickName :  : 用户昵称
                params: status :  : 会员状态 0：禁用 1：启用
                params: type :  : 用户类型 0：注册 1：非注册
                params: memberSystemSource :  : 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
                params: size :  : 每页数据数
                params: current :  : 当前页数
                params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
                params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
                params: ownerFlag :  : 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
                params: createTimeStart :  : 用户创建开始时间
                params: createTimeEnd :  : 用户创建结束时间
                params: regisTimeBegin :  : 会员注册开始时间
                params: regisTimeEnd :  : 会员注册结束时间
                params: lastLoginTimeStart :  : 用户最近登录开始时间
                params: lastLoginTimeEnd :  : 用户最近登录结束时间
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        lastLoginTimeEnd = self.get_list_choice(lastLoginTimeEnd, list_or_dict=None, key="lastLoginTimeEnd")
        createTimeStart = self.get_list_choice(createTimeStart, list_or_dict=None, key="createTimeStart")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        memberSystemSource = self.get_list_choice(memberSystemSource, list_or_dict=None, key="memberSystemSource")
        userSystemSource = self.get_list_choice(userSystemSource, list_or_dict=None, key="userSystemSource")
        createTimeEnd = self.get_list_choice(createTimeEnd, list_or_dict=None, key="createTimeEnd")
        regisTimeEnd = self.get_list_choice(regisTimeEnd, list_or_dict=None, key="regisTimeEnd")
        lastLoginTimeStart = self.get_list_choice(lastLoginTimeStart, list_or_dict=None, key="lastLoginTimeStart")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        ownerFlag = self.get_list_choice(ownerFlag, list_or_dict=None, key="ownerFlag")
        regisTimeBegin = self.get_list_choice(regisTimeBegin, list_or_dict=None, key="regisTimeBegin")
        activitySource = self.get_list_choice(activitySource, list_or_dict=None, key="activitySource")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        type = self.get_list_choice(type, list_or_dict=None, key="type")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_page(**_kwargs)

        self.assert_common_user4c_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户列表-详情-车辆信息-Y")
    def common_user4c_vehicleinfo(self, size=10, userId="$None$", mobile="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/common/user4C/vehicleInfo
                params: mobile :  : 用户手机号码
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_vehicleinfo(**_kwargs)

        self.assert_common_user4c_vehicleinfo(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户中心-用户基本信息-Y")
    def common_user4c_getbyid(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/getById
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_getbyid(**_kwargs)

        self.assert_common_user4c_getbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户中心-编辑官方账号-Y")
    def common_user4c_updateuser(self, userId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/common/user4C/updateUser
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_updateuser(**_kwargs)

        self.assert_common_user4c_updateuser(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户列表-导出-Y")
    def common_user4c_download(self, userId="$None$", lastLoginTimeEnd="$None$", userIds="$None$", createTimeStart="$None$", nickName="$None$", memberSystemSource="$None$", userSystemSource="$None$", createTimeEnd="$None$", regisTimeEnd="$None$", lastLoginTimeStart="$None$", mobile="$None$", downloadType="$None$", ownerFlag="$None$", regisTimeBegin="$None$", activitySource="$None$", status="$None$", type="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/download
                params: mobile :  : 用户手机号
                params: nickName :  : 用户昵称
                params: status :  : 会员状态 0：禁用 1：启用
                params: type :  : 用户类型 0：注册 1：非注册
                params: memberSystemSource :  : 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
                params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
                params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
                params: ownerFlag :  : 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
                params: createTimeStart :  : 用户创建开始时间
                params: createTimeEnd :  : 用户创建结束时间
                params: regisTimeBegin :  : 会员注册开始时间
                params: regisTimeEnd :  : 会员注册结束时间
                params: lastLoginTimeStart :  : 会员最近登录开始时间
                params: lastLoginTimeEnd :  : 会员最近登录结束时间
                params: downloadType :  : 导出类型 1: 条件导出 2: 批量导出
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        lastLoginTimeEnd = self.get_list_choice(lastLoginTimeEnd, list_or_dict=None, key="lastLoginTimeEnd")
        userIds = self.get_list_choice(userIds, list_or_dict=None, key="userIds")
        createTimeStart = self.get_list_choice(createTimeStart, list_or_dict=None, key="createTimeStart")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        memberSystemSource = self.get_list_choice(memberSystemSource, list_or_dict=None, key="memberSystemSource")
        userSystemSource = self.get_list_choice(userSystemSource, list_or_dict=None, key="userSystemSource")
        createTimeEnd = self.get_list_choice(createTimeEnd, list_or_dict=None, key="createTimeEnd")
        regisTimeEnd = self.get_list_choice(regisTimeEnd, list_or_dict=None, key="regisTimeEnd")
        lastLoginTimeStart = self.get_list_choice(lastLoginTimeStart, list_or_dict=None, key="lastLoginTimeStart")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        downloadType = self.get_list_choice(downloadType, list_or_dict=None, key="downloadType")
        ownerFlag = self.get_list_choice(ownerFlag, list_or_dict=None, key="ownerFlag")
        regisTimeBegin = self.get_list_choice(regisTimeBegin, list_or_dict=None, key="regisTimeBegin")
        activitySource = self.get_list_choice(activitySource, list_or_dict=None, key="activitySource")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        type = self.get_list_choice(type, list_or_dict=None, key="type")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_download(**_kwargs)

        self.assert_common_user4c_download(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户列表-导出前置判断-Y")
    def common_user4c_beforepointsexport(self, userId="$None$", lastLoginTimeEnd="$None$", userIds="$None$", createTimeStart="$None$", nickName="$None$", memberSystemSource="$None$", userSystemSource="$None$", createTimeEnd="$None$", regisTimeEnd="$None$", lastLoginTimeStart="$None$", mobile="$None$", downloadType="$None$", ownerFlag="$None$", regisTimeBegin="$None$", activitySource="$None$", status="$None$", type="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/beforePointsExport
                params: mobile :  : 用户手机号
                params: nickName :  : 用户昵称
                params: status :  : 账号状态 0：禁用 1：启用
                params: type :  : 用户类型 0：注册 1：非注册
                params: memberSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5
                params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
                params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
                params: ownerFlag :  :  1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
                params: createTimeStart :  : 用户创建开始时间
                params: createTimeEnd :  : 用户创建结束时间
                params: regisTimeBegin :  : 会员注册开始时间
                params: regisTimeEnd :  : 会员注册结束时间
                params: lastLoginTimeStart :  : 会员最近登录开始时间
                params: lastLoginTimeEnd :  : 会员最近登录结束时间
                params: downloadType :  : 1：条件导出 2：批量导出
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        lastLoginTimeEnd = self.get_list_choice(lastLoginTimeEnd, list_or_dict=None, key="lastLoginTimeEnd")
        userIds = self.get_list_choice(userIds, list_or_dict=None, key="userIds")
        createTimeStart = self.get_list_choice(createTimeStart, list_or_dict=None, key="createTimeStart")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        memberSystemSource = self.get_list_choice(memberSystemSource, list_or_dict=None, key="memberSystemSource")
        userSystemSource = self.get_list_choice(userSystemSource, list_or_dict=None, key="userSystemSource")
        createTimeEnd = self.get_list_choice(createTimeEnd, list_or_dict=None, key="createTimeEnd")
        regisTimeEnd = self.get_list_choice(regisTimeEnd, list_or_dict=None, key="regisTimeEnd")
        lastLoginTimeStart = self.get_list_choice(lastLoginTimeStart, list_or_dict=None, key="lastLoginTimeStart")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        downloadType = self.get_list_choice(downloadType, list_or_dict=None, key="downloadType")
        ownerFlag = self.get_list_choice(ownerFlag, list_or_dict=None, key="ownerFlag")
        regisTimeBegin = self.get_list_choice(regisTimeBegin, list_or_dict=None, key="regisTimeBegin")
        activitySource = self.get_list_choice(activitySource, list_or_dict=None, key="activitySource")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        type = self.get_list_choice(type, list_or_dict=None, key="type")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_beforepointsexport(**_kwargs)

        self.assert_common_user4c_beforepointsexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户列表-新增-Y")
    def common_user4c_insert(self, explain="$None$", avatarUrl="$None$", nickName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/common/user4C/insert
                params: avatarUrl : text : String；图片地址
                params: explain : text : String；简介
                params: nickName : text : String；昵称
                params: headers : 请求头
        """
        explain = self.get_value_choice(explain, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        avatarUrl = self.get_value_choice(avatarUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        nickName = self.get_value_choice(nickName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_insert(**_kwargs)

        self.assert_common_user4c_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户中心-禁用/启用用户-Y")
    def common_user4c_editstatus(self, userId="$None$", status="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/common/user4C/editStatus
                params: status : number : 是否启用0：禁用 1：启用
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_editstatus(**_kwargs)

        self.assert_common_user4c_editstatus(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="导出用户审核列表-Y")
    def common_user4c_auditexport(self, userId="$None$", userIds="$None$", registerType="$None$", userLabel="$None$", phone="$None$", userType="$None$", downloadType="$None$", ownerFlag="$None$", nickName="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/auditExport
                params: phone :  : 手机号
                params: nickName :  : 昵称
                params: ownerFlag :  : 是否车主认证1：是0：否
                params: userLabel :  : 用户标签
                params: registerType :  : 用户来源
                params: userType :  : 用户类型
                params: downloadType :  : 下载类型1：根据搜索条件导出2：多选导出
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        userIds = self.get_list_choice(userIds, list_or_dict=None, key="userIds")
        registerType = self.get_list_choice(registerType, list_or_dict=None, key="registerType")
        userLabel = self.get_list_choice(userLabel, list_or_dict=None, key="userLabel")
        phone = self.get_list_choice(phone, list_or_dict=None, key="phone")
        userType = self.get_list_choice(userType, list_or_dict=None, key="userType")
        downloadType = self.get_list_choice(downloadType, list_or_dict=None, key="downloadType")
        ownerFlag = self.get_list_choice(ownerFlag, list_or_dict=None, key="ownerFlag")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_auditexport(**_kwargs)

        self.assert_common_user4c_auditexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="根据id查询用户身份-Y")
    def common_user4c_identity(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/identity
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_identity(**_kwargs)

        self.assert_common_user4c_identity(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="更新审核状态-Y")
    def common_user4c_updateaudit(self, userId="$None$", auditType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/common/user4C/updateAudit
                params: auditType : integer : 认证类型（1：注销审核单据，2：车主认证审核单据）
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        auditType = self.get_value_choice(auditType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_updateaudit(**_kwargs)

        self.assert_common_user4c_updateaudit(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="根据用户审核状态搜索列表-Y")
    def common_user4c_auditlist(self, userId="$None$", userName="$None$", registerType="$None$", pageNum=1, pageSize="$None$", mobile="$None$", checkStatus="$None$", nickName="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/auditList
                params: mobile :  : 手机号
                params: nickName :  : 用户昵称
                params: userName :  : 用户实名姓名
                params: registerType :  : 用户来源
                params: pageSize :  : 每页数量
                params: pageNum :  : 当前页数
                params: checkStatus :  : 状态 0-正常 1-审核中 2-通过3-审核不通过
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        registerType = self.get_list_choice(registerType, list_or_dict=None, key="registerType")
        pageSize = self.get_list_choice(pageSize, list_or_dict=None, key="pageSize")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        checkStatus = self.get_list_choice(checkStatus, list_or_dict=None, key="checkStatus")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_auditlist(**_kwargs)

        self.assert_common_user4c_auditlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户信息积分详情-？历史接口")
    def common_user4c_getuserpoints(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/common/user4C/getUserPoints
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user4c.common_user4c_getuserpoints(**_kwargs)

        self.assert_common_user4c_getuserpoints(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_safecode import AssertsContentSafecode
from service.app_a.apis.content import apis_content_safecode


class FunsContentSafecode(AssertsContentSafecode):
    @allure.step(title="安全码关闭-Y")
    def content_safecode_close(self, safeCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/safeCode/close
                params: safeCode : string : 安全码
                params: headers : 请求头
        """
        safeCode = self.get_value_choice(safeCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_safecode.content_safecode_close(**_kwargs)

        self.assert_content_safecode_close(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="安全码新增-Y")
    def content_safecode_add(self, safeCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/safeCode/add
                params: safeCode : string : 安全码
                params: headers : 请求头
        """
        safeCode = self.get_value_choice(safeCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_safecode.content_safecode_add(**_kwargs)

        self.assert_content_safecode_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="安全码校验-Y")
    def content_safecode_verify(self, safeCode="$None$", _assert=True,  **kwargs):
        """
            url=/content/safeCode/verify
                params: safeCode :  : 安全码
                params: headers : 请求头
        """
        safeCode = self.get_list_choice(safeCode, list_or_dict=None, key="safeCode")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_safecode.content_safecode_verify(**_kwargs)

        self.assert_content_safecode_verify(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="安全码状态查询-Y")
    def content_safecode_getstatus(self, _assert=True,  **kwargs):
        """
            url=/content/safeCode/getStatus
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_safecode.content_safecode_getstatus(**_kwargs)

        self.assert_content_safecode_getstatus(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="安全码重置-Y")
    def content_safecode_reset(self, safeCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/safeCode/reset
                params: safeCode : string : 安全码
                params: headers : 请求头
        """
        safeCode = self.get_value_choice(safeCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_safecode.content_safecode_reset(**_kwargs)

        self.assert_content_safecode_reset(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_contentmanager import SqlsContentContentmanager


class AssertsContentContentmanager(SqlsContentContentmanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_contentmanager_commentlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_contentmanager_commentlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["contentId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_adv import AssertsContentAdv
from service.app_a.apis.content import apis_content_adv


class FunsContentAdv(AssertsContentAdv):
    @allure.step(title="点位内容-保存运营端配置(更新、新增)（930）-Y")
    def content_adv_save(self, jumpContent="$None$", advPicUrl="$None$", advText="$None$", jumpType="$None$", advId="$None$", advLinkUrl="$None$", bindingFlag="$None$", version="$None$", advSerial="$None$", advPlaceId="$None$", pictureList="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/save
                params: advPlaceId : number : 左侧列表选中ID
                params: advPicUrl : string : 图片地址
                params: advText : string : 文字描述
                params: advSerial : string : 排序
                params: jumpType : number : 跳转类型
                params: jumpContent : string : 跳转内容
                params: advId : number : 点位ID（更新时必传）
                params: version : string : 绑定的车系（60s,80v）
                params: advLinkUrl : string : 爱车海报填写地址/url跳转地址
                params: bindingFlag : number : 车辆绑定标识 1绑定 0未绑定
                params: pictureList : array : 当跳转类型为16：图片新增字段
                type : string : None
                params: headers : 请求头
        """
        jumpContent = self.get_value_choice(jumpContent, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advPicUrl = self.get_value_choice(advPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advText = self.get_value_choice(advText, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        jumpType = self.get_value_choice(jumpType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advId = self.get_value_choice(advId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advLinkUrl = self.get_value_choice(advLinkUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        bindingFlag = self.get_value_choice(bindingFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        version = self.get_value_choice(version, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advSerial = self.get_value_choice(advSerial, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advPlaceId = self.get_value_choice(advPlaceId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        pictureList = self.get_value_choice(pictureList, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_save(**_kwargs)

        self.assert_content_adv_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-修改点位信息-Y")
    def content_adv_updateessayadvlist(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/updateEssayAdvList
                params: essayId : string :
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_updateessayadvlist(**_kwargs)

        self.assert_content_adv_updateessayadvlist(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-文章置顶-Y")
    def content_adv_settopflag(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/setTopFlag
                params: essayId : text : 文章主键Id
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_settopflag(**_kwargs)

        self.assert_content_adv_settopflag(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-点位查询接口-Y")
    def content_adv_advplacelist(self, advPlaceId="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/advPlaceList
                params: advPlaceId :  : 广告点位主键：
                【发现-推荐】轮播图
                【发现-推荐】快捷入口
                【发现-资讯】金刚区
                【爱车】试驾页轮播
                【发现-推荐】精选内容
                【爱车-智能车控】
                【爱车-购车帮助】
                【我的-邀请好友】海报图
                【我的-积分】积分规则说明
                【爱车-购车帮助（新）】
                params: headers : 请求头
        """
        advPlaceId = self.get_list_choice(advPlaceId, list_or_dict=None, key="advPlaceId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_advplacelist(**_kwargs)

        self.assert_content_adv_advplacelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-删除-Y")
    def content_adv_delete(self, advId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/delete
                params: advId : string : 点位ID
                params: headers : 请求头
        """
        advId = self.get_value_choice(advId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_delete(**_kwargs)

        self.assert_content_adv_delete(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位查询(930版本)-Y")
    def content_adv_detailadmin(self, advPlaceId="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/detailAdmin
                params: advPlaceId :  : 广告位id
                params: headers : 请求头
        """
        advPlaceId = self.get_list_choice(advPlaceId, list_or_dict=None, key="advPlaceId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_detailadmin(**_kwargs)

        self.assert_content_adv_detailadmin(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-新增广告位（点位）-Y")
    def content_adv_saveall(self, jumpType="$None$", advPlaceId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/saveAll
                params: advPlaceId : number : 广告位ID
                params: jumpType : integer : 备注中查看状态信息
                params: headers : 请求头
        """
        jumpType = self.get_value_choice(jumpType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advPlaceId = self.get_value_choice(advPlaceId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_saveall(**_kwargs)

        self.assert_content_adv_saveall(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-根据跳转类型选择跳转内容（930）-Y")
    def content_adv_jumpcontent(self, typeCode="$None$", keyWord="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/jumpContent
                params: typeCode :  : 跳转类型
                params: keyWord :  :
                params: headers : 请求头
        """
        typeCode = self.get_list_choice(typeCode, list_or_dict=None, key="typeCode")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_jumpcontent(**_kwargs)

        self.assert_content_adv_jumpcontent(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-查询推荐页内容-Y")
    def content_adv_detailcontentadmin(self, size=10, current=1, orderByCommentCnt="$None$", essayKeyWords="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/detailConTentAdmin
                params: current :  :
                params: size :  :
                params: essayKeyWords :  :
                params: orderByCommentCnt :  :
                params: headers : 请求头
        """
        orderByCommentCnt = self.get_list_choice(orderByCommentCnt, list_or_dict=None, key="orderByCommentCnt")
        essayKeyWords = self.get_list_choice(essayKeyWords, list_or_dict=None, key="essayKeyWords")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_detailcontentadmin(**_kwargs)

        self.assert_content_adv_detailcontentadmin(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-查询跳转类型-Y")
    def content_adv_jumptypelist(self, _assert=True,  **kwargs):
        """
            url=/content/adv/jumpTypeList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_jumptypelist(**_kwargs)

        self.assert_content_adv_jumptypelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位内容-取消推荐-Y")
    def content_adv_cancelrecommend(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/adv/cancelRecommend
                params: essayId : string : 文章主键Id
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_cancelrecommend(**_kwargs)

        self.assert_content_adv_cancelrecommend(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="点位-根据点位主键查询点位信息(930版本)")
    def content_adv_detail(self, advPlaceId="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/detail
                params: advPlaceId :  : 广告点位主键
                1:[发现-推荐]轮播图
                2:[发现-推荐]快捷入口
                5:[发现-资讯]金刚区
                6:[爱车]试驾页轮播
                8:[发现-推荐]精选内容
                9:[爱车-智能车控]
                10:[爱车-购车帮助]
                11:[我的-邀请好友]海报图
                12:[我的-积分]积分规则明细
                params: headers : 请求头
        """
        advPlaceId = self.get_list_choice(advPlaceId, list_or_dict=None, key="advPlaceId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_adv.content_adv_detail(**_kwargs)

        self.assert_content_adv_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.common.asserts_common_systemversion import AssertsCommonSystemversion
from service.app_a.apis.common import apis_common_systemversion


class FunsCommonSystemversion(AssertsCommonSystemversion):
    @allure.step(title="保存版本信息-Y")
    def common_systemversion_save(self, remark="$None$", size=10, name="$None$", force="$None$", version="$None$", downloadUrl="$None$", versionId="$None$", content="$None$", publishStatus="$None$", classify="$None$", _assert=True,  **kwargs):
        """
            url=/common/systemversion/save
                params: version : string : 版本号
                params: name : string : 版本名称
                params: content : string : 更新内容
                params: remark : string : 备注
                params: classify : string :  Android或IOS
                params: force : string : 强制更新0.否1.是
                params: downloadUrl : string : 下载路径
                params: size : string : 大小
                params: versionId : number : 主键，更新传，新增不传
                params: publishStatus : number : 0. 未发布 1.已发布
                params: headers : 请求头
        """
        remark = self.get_list_choice(remark, list_or_dict=None, key="remark")
        name = self.get_list_choice(name, list_or_dict=None, key="name")
        force = self.get_list_choice(force, list_or_dict=None, key="force")
        version = self.get_list_choice(version, list_or_dict=None, key="version")
        downloadUrl = self.get_list_choice(downloadUrl, list_or_dict=None, key="downloadUrl")
        versionId = self.get_list_choice(versionId, list_or_dict=None, key="versionId")
        content = self.get_list_choice(content, list_or_dict=None, key="content")
        publishStatus = self.get_list_choice(publishStatus, list_or_dict=None, key="publishStatus")
        classify = self.get_list_choice(classify, list_or_dict=None, key="classify")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_systemversion.common_systemversion_save(**_kwargs)

        self.assert_common_systemversion_save(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="查询版本信息-Y")
    def common_systemversion_page(self, _assert=True,  **kwargs):
        """
            url=/common/systemversion/page
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_systemversion.common_systemversion_page(**_kwargs)

        self.assert_common_systemversion_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_question import AssertsContentQuestion
from service.app_a.apis.content import apis_content_question


class FunsContentQuestion(AssertsContentQuestion):
    @allure.step(title="问答-回复问题-Y")
    def content_question_answerquestion(self, questionId="$None$", answerContent="$None$", author="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/question/answerQuestion
                params: questionId : string : 问题主键
                params: answerContent : string : 回答内容
                params: author : number : 作者
                params: headers : 请求头
        """
        questionId = self.get_value_choice(questionId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        answerContent = self.get_value_choice(answerContent, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        author = self.get_value_choice(author, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_question.content_question_answerquestion(**_kwargs)

        self.assert_content_question_answerquestion(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="问答-回答撤回归档-Y")
    def content_question_revoke(self, operaType="$None$", questionId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/question/revoke
                params: operaType : string : 操作类型3：撤回4：归档
                params: questionId : string : 回复主键
                params: headers : 请求头
        """
        operaType = self.get_value_choice(operaType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        questionId = self.get_value_choice(questionId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_question.content_question_revoke(**_kwargs)

        self.assert_content_question_revoke(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="问答-搜索问题列表-Y")
    def content_question_getmanegequestionlist(self, size=10, keyWord="$None$", endTime="$None$", startTime="$None$", mobile="$None$", status="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/question/getManegeQuestionList
                params: keyWord :  : 关键字
                params: mobile :  : 发布人手机号
                params: startTime :  : 搜索起始时间
                params: endTime :  : 搜索结束时间
                params: status :  : 问答状态1：已回复、0：待回复、3：已撤回、4：已归档
                params: size :  : 每页数据量
                params: current :  : 页数
                params: headers : 请求头
        """
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_question.content_question_getmanegequestionlist(**_kwargs)

        self.assert_content_question_getmanegequestionlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="问答-获取问题详情页面-Y")
    def content_question_getbyid(self, questionId="$None$", _assert=True,  **kwargs):
        """
            url=/content/question/getById
                params: questionId :  : 问题主键
                params: headers : 请求头
        """
        questionId = self.get_list_choice(questionId, list_or_dict=None, key="questionId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_question.content_question_getbyid(**_kwargs)

        self.assert_content_question_getbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.common.asserts_common_clue import AssertsCommonClue
from service.app_a.apis.common import apis_common_clue


class FunsCommonClue(AssertsCommonClue):
    @allure.step(title="用户列表-详情-查询线索-Y")
    def common_clue_getclueuserpage(self, userId="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/common/clue/getClueUserPage
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_clue.common_clue_getclueuserpage(**_kwargs)

        self.assert_common_clue_getclueuserpage(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.material.asserts_content_material_getmateriallist import AssertsContentMaterialGetmateriallist
from service.app_a.apis.content.material import apis_content_material_getmateriallist


class FunsContentMaterialGetmateriallist(AssertsContentMaterialGetmateriallist):
    @allure.step(title="素材-根据素材组获取素材列表_copy")
    def content_material_getmateriallist_1659319316474(self, size=10, groupId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/material/getMaterialList_1659319316474
                params: groupId :  : 分组主键
                params: size :  : 每页数据数
                params: current :  : 当前页
                params: headers : 请求头
        """
        groupId = self.get_list_choice(groupId, list_or_dict=None, key="groupId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_material_getmateriallist.content_material_getmateriallist_1659319316474(**_kwargs)

        self.assert_content_material_getmateriallist_1659319316474(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/essaycomment/manageAdd")
def content_essaycomment_manageadd(author=None, content=None, essayId=None, parentId=None, headers=None, **kwargs):
    """
    后台管理-新建评论/回复1030-Y
    up_time=1675735107

    params: essayId : string : 文章id
    params: author : string : 评论人id
    params: content : string : 内容
    params: parentId : string : 所回复评论的id 新建评论不用传 回复要传
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功
    params: msg : string : 
    params: data : null : 
    """
    _method = "POST"
    _url = "/content/essaycomment/manageAdd"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章id
        "author": author,  # 评论人id
        "content": content,  # 内容
        "parentId": parentId,  # 所回复评论的id 新建评论不用传 回复要传
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_activitymanager import AssertsContentActivitymanager
from service.app_a.apis.content import apis_content_activitymanager


class FunsContentActivitymanager(AssertsContentActivitymanager):
    @allure.step(title="活动 -修改报名人数(930)-Y")
    def content_activitymanager_updateperson(self, needLimitPeople="$None$", limitPeople="$None$", activityId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/updatePerson
                params: activityId : string : 活动Id
                params: needLimitPeople : string : 是否限制 0 不限制 1限制
                params: limitPeople : number : 限制人数
                params: headers : 请求头
        """
        needLimitPeople = self.get_value_choice(needLimitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        limitPeople = self.get_value_choice(limitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_updateperson(**_kwargs)

        self.assert_content_activitymanager_updateperson(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动 -修改报名时间-Y")
    def content_activitymanager_updateenrolltime(self, enrollStartTime="$None$", enrollTime="$None$", activityId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/updateEnrollTime
                params: activityId : string : 活动Id
                params: enrollStartTime : string : 报名开始时间
                params: enrollTime : string : 报名结束时间
                params: headers : 请求头
        """
        enrollStartTime = self.get_value_choice(enrollStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        enrollTime = self.get_value_choice(enrollTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_updateenrolltime(**_kwargs)

        self.assert_content_activitymanager_updateenrolltime(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动列表查询（930版本）-Y")
    def content_activitymanager_page(self, target="$None$", city="$None$", activityId="$None$", province="$None$", endTime="$None$", pushTimeSort="$None$", title="$None$", status="$None$", activityTimeSort="$None$", beginTime="$None$", createTimeSort="$None$", _assert=True,  **kwargs):
        """
            url=/content/activityManager/page
                params: activityId :  :
                params: title :  :
                params: beginTime :  : 2022-01-18 00:00:00 （一定要带上00:00:00）
                params: endTime :  : 2022-01-18 23:59:59 （一定要带上23:59:59）
                params: target :  : 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
                params: status :  : 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
                params: province :  : 省（编码 areaId）全国则不需要传值
                params: city :  : 市（编码areaId）
                params: createTimeSort :  : 创建时间排序（DESC（倒序））|ASC（正序））
                params: activityTimeSort :  : 活动时间排序（DESC|ASC）
                params: pushTimeSort :  : 发布时间排序（DESC|ASC）
                params: headers : 请求头
        """
        target = self.get_list_choice(target, list_or_dict=None, key="target")
        city = self.get_list_choice(city, list_or_dict=None, key="city")
        activityId = self.get_list_choice(activityId, list_or_dict=None, key="activityId")
        province = self.get_list_choice(province, list_or_dict=None, key="province")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        pushTimeSort = self.get_list_choice(pushTimeSort, list_or_dict=None, key="pushTimeSort")
        title = self.get_list_choice(title, list_or_dict=None, key="title")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        activityTimeSort = self.get_list_choice(activityTimeSort, list_or_dict=None, key="activityTimeSort")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")
        createTimeSort = self.get_list_choice(createTimeSort, list_or_dict=None, key="createTimeSort")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_page(**_kwargs)

        self.assert_content_activitymanager_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动操作停止报名和结束活动-Y")
    def content_activitymanager_actinfoupdate(self, operationType="$None$", activityId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/actInfoUpdate
                params: activityId : text : 活动ID
                params: operationType : text : 1停止报名 2活动结束
                params: headers : 请求头
        """
        operationType = self.get_value_choice(operationType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_actinfoupdate(**_kwargs)

        self.assert_content_activitymanager_actinfoupdate(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="设置活动权重(930版本)-Y")
    def content_activitymanager_setactivitysort(self, activityId="$None$", sort="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/setActivitySort
                params: activityId : string : 活动Id
                params: sort : number : 权重
                params: headers : 请求头
        """
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sort = self.get_value_choice(sort, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_setactivitysort(**_kwargs)

        self.assert_content_activitymanager_setactivitysort(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="获取活动详情-Y")
    def content_activitymanager_getactivityinfo_(self, activityId="$None$", _assert=True,  **kwargs):
        """
            url=/content/activityManager/getActivityInfo/{activityId}
                params: activityId :  :
                params: headers : 请求头
        """
        activityId = self.get_list_choice(activityId, list_or_dict=None, key="activityId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_getactivityinfo_(**_kwargs)

        self.assert_content_activitymanager_getactivityinfo_(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动置顶/取消置顶-Y")
    def content_activitymanager_activitytop_(self, topFlag="$None$", activityId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/activityTop/
                params: activityId : text : 活动ID
                params: topFlag : text : 0不置顶  1置顶
                params: headers : 请求头
        """
        topFlag = self.get_value_choice(topFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_activitytop_(**_kwargs)

        self.assert_content_activitymanager_activitytop_(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动报名用户数据导出-Y")
    def content_activitymanager_activityjoinuserexport(self, activityId="$None$", _assert=True,  **kwargs):
        """
            url=/content/activityManager/activityJoinUserExport
                params: activityId :  : 活动Id
                params: headers : 请求头
        """
        activityId = self.get_list_choice(activityId, list_or_dict=None, key="activityId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_activityjoinuserexport(**_kwargs)

        self.assert_content_activitymanager_activityjoinuserexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动新增-Y")
    def content_activitymanager_save(self, reason="$None$", endTime="$None$", enrollStartTime="$None$", county="$None$", content="$None$", limitPeople="$None$", beginTime="$None$", activityAddr="$None$", agreementId="$None$", coordinate="$None$", publishType="$None$", title="$None$", status="$None$", customerGroup="$None$", activityPicUrl="$None$", needLimitPeople="$None$", activityId="$None$", province="$None$", activityPicURL="$None$", enrollTime="$None$", needArea="$None$", city="$None$", authId="$None$", publishTime="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/save
                params: activityId : text :
                params: title : text :
                params: reason : text :
                params: activityPicUrl : text :
                params: beginTime : text :
                params: endTime : text : 汉字
                params: needArea : text : 汉字
                params: province : text : 汉字
                params: city : text : 34.232342,112.342345
                params: county : text :
                params: coordinate : text :
                params: needLimitPeople : text :
                params: limitPeople : text :
                params: enrollStartTime : text :
                params: enrollTime : text :
                params: publishType : text : 地图获取
                params: publishTime : text :
                params: content : text :
                params: authId : text :
                params: status : text :
                params: activityAddr : text :
                params: customerGroup : text :
                params: activityPicURL : string : 活动封面图
                params: agreementId : number : 协议ID
                params: headers : 请求头
        """
        reason = self.get_value_choice(reason, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        endTime = self.get_value_choice(endTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        enrollStartTime = self.get_value_choice(enrollStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        county = self.get_value_choice(county, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        limitPeople = self.get_value_choice(limitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        beginTime = self.get_value_choice(beginTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityAddr = self.get_value_choice(activityAddr, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        agreementId = self.get_value_choice(agreementId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        coordinate = self.get_value_choice(coordinate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishType = self.get_value_choice(publishType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerGroup = self.get_value_choice(customerGroup, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityPicUrl = self.get_value_choice(activityPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        needLimitPeople = self.get_value_choice(needLimitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        province = self.get_value_choice(province, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityPicURL = self.get_value_choice(activityPicURL, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        enrollTime = self.get_value_choice(enrollTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        needArea = self.get_value_choice(needArea, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        city = self.get_value_choice(city, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        authId = self.get_value_choice(authId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishTime = self.get_value_choice(publishTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_save(**_kwargs)

        self.assert_content_activitymanager_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动编辑（930版本）-Y")
    def content_activitymanager_update(self, reason="$None$", endTime="$None$", enrollStartTime="$None$", county="$None$", content="$None$", limitPeople="$None$", beginTime="$None$", activityAddr="$None$", coordinate="$None$", publishType="$None$", title="$None$", status="$None$", customerGroup="$None$", activityPicUrl="$None$", needLimitPeople="$None$", activityId="$None$", province="$None$", activityPicURL="$None$", enrollTime="$None$", city="$None$", needArea="$None$", authId="$None$", publishTime="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/update
                params: activityId : text :
                params: title : text :
                params: reason : text :
                params: activityPicUrl : text :
                params: beginTime : text :
                params: endTime : text :
                params: province : text : 汉字
                params: city : text : 汉字
                params: county : text :
                params: coordinate : text : 34.232342,112.342345
                params: limitPeople : text :
                params: enrollTime : text :
                params: publishType : text :
                params: publishTime : text :
                params: content : text :
                params: authId : text :
                params: activityPicURL : string : 活动封面图
                params: needArea : string : 是否需要区域
                params: needLimitPeople : string : 是否需要人数限制
                params: enrollStartTime : string : 报名开始时间
                params: status : integer : 活动状态: 不传查全部
                * 2:待审核
                * 3:审核通过
                * 4:待上架
                * 5:已上架
                * 6:审核不通过
                * 9:停止报名
                * 10:已结束
                * 11:已下架
                * 12:已删除
                params: activityAddr : string : 活动地址
                params: customerGroup : string : 参与对象（1：全部用户，2：车主用户，3：非车主用户）
                params: headers : 请求头
        """
        reason = self.get_value_choice(reason, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        endTime = self.get_value_choice(endTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        enrollStartTime = self.get_value_choice(enrollStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        county = self.get_value_choice(county, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        limitPeople = self.get_value_choice(limitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        beginTime = self.get_value_choice(beginTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityAddr = self.get_value_choice(activityAddr, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        coordinate = self.get_value_choice(coordinate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishType = self.get_value_choice(publishType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerGroup = self.get_value_choice(customerGroup, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityPicUrl = self.get_value_choice(activityPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        needLimitPeople = self.get_value_choice(needLimitPeople, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        province = self.get_value_choice(province, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityPicURL = self.get_value_choice(activityPicURL, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        enrollTime = self.get_value_choice(enrollTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        city = self.get_value_choice(city, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        needArea = self.get_value_choice(needArea, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        authId = self.get_value_choice(authId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishTime = self.get_value_choice(publishTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_update(**_kwargs)

        self.assert_content_activitymanager_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动发布状态修改(930)-Y")
    def content_activitymanager_publishupdate(self, activityId="$None$", status="$None$", publishStatus="$None$", activityIds="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/publishUpdate
                params: activityIds : text : 单个记录修改传["xxxxx"]
                params: publishStatus : text :
                params: activityId : string : 活动Id
                params: status : number : //状态: 1.新建 2.待审核 3.审核通过 4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架；查询时候传的状态：12.已删除
                params: headers : 请求头
        """
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishStatus = self.get_value_choice(publishStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityIds = self.get_value_choice(activityIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_publishupdate(**_kwargs)

        self.assert_content_activitymanager_publishupdate(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动审核状态修改-Y")
    def content_activitymanager_statusupdate(self, activityIds="$None$", checkStatus="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/statusUpdate
                params: checkStatus : text :
                params: activityIds : array : 活动IDs
                type : string : None
                params: headers : 请求头
        """
        activityIds = self.get_value_choice(activityIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        checkStatus = self.get_value_choice(checkStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_statusupdate(**_kwargs)

        self.assert_content_activitymanager_statusupdate(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动报名状态修改-Y")
    def content_activitymanager_enrollupdate(self, checkEnroll="$None$", activityIds="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/activityManager/enrollUpdate
                params: activityIds : text : 单个记录修改传["xxxxx"]
                params: checkEnroll : text :
                params: headers : 请求头
        """
        checkEnroll = self.get_value_choice(checkEnroll, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityIds = self.get_value_choice(activityIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_enrollupdate(**_kwargs)

        self.assert_content_activitymanager_enrollupdate(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动数据导出-Y")
    def content_activitymanager_activityexport(self, target="$None$", city="$None$", activityId="$None$", province="$None$", endTime="$None$", pushTimeSort="$None$", title="$None$", status="$None$", activityTimeSort="$None$", beginTime="$None$", createTimeSort="$None$", _assert=True,  **kwargs):
        """
            url=/content/activityManager/activityExport
                params: activityId :  :
                params: title :  :
                params: beginTime :  : 2022-01-18 00:00:00 （一定要带上00:00:00）
                params: endTime :  : 2022-01-18 23:59:59 （一定要带上23:59:59）
                params: target :  : 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
                params: status :  : 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
                params: province :  : 省（编码 areaId）全国则不需要传值
                params: city :  : 市（编码areaId）
                params: createTimeSort :  : 创建时间排序（DESC（倒序））|ASC（正序））
                params: activityTimeSort :  : 活动时间排序（DESC|ASC）
                params: pushTimeSort :  : 发布时间排序（DESC|ASC）
                params: headers : 请求头
        """
        target = self.get_list_choice(target, list_or_dict=None, key="target")
        city = self.get_list_choice(city, list_or_dict=None, key="city")
        activityId = self.get_list_choice(activityId, list_or_dict=None, key="activityId")
        province = self.get_list_choice(province, list_or_dict=None, key="province")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        pushTimeSort = self.get_list_choice(pushTimeSort, list_or_dict=None, key="pushTimeSort")
        title = self.get_list_choice(title, list_or_dict=None, key="title")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        activityTimeSort = self.get_list_choice(activityTimeSort, list_or_dict=None, key="activityTimeSort")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")
        createTimeSort = self.get_list_choice(createTimeSort, list_or_dict=None, key="createTimeSort")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_activityexport(**_kwargs)

        self.assert_content_activitymanager_activityexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="活动状态流程-Y")
    def content_activitymanager_listlog(self, activityId="$None$", _assert=True,  **kwargs):
        """
            url=/content/activityManager/listLog
                params: activityId :  : 活动id
                params: headers : 请求头
        """
        activityId = self.get_list_choice(activityId, list_or_dict=None, key="activityId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_activitymanager.content_activitymanager_listlog(**_kwargs)

        self.assert_content_activitymanager_listlog(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/userPointsManage/userPointsExport")
def common_userpointsmanage_userpointsexport(logIds=None, endTime=None, mobile=None, nickName=None, beginTime=None, headers=None, **kwargs):
    """
    用户积分列表导出-历史接口
    up_time=1676338877

    params: nickName :  : 用户昵称
    params: mobile :  : 用户手机号
    params: beginTime :  : 注册时间查询范围--开始时间
    params: endTime :  : 注册时间查询范围--结束时间
    params: logIds :  : 积分明细Id，用于积分导出，如果传参表示勾选数据导出
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/common/userPointsManage/userPointsExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "nickName": nickName,  # 用户昵称
        "mobile": mobile,  # 用户手机号
        "beginTime": beginTime,  # 注册时间查询范围--开始时间
        "endTime": endTime,  # 注册时间查询范围--结束时间
        "logIds": logIds,  # 积分明细Id，用于积分导出，如果传参表示勾选数据导出
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/userPointsManage/page")
def common_userpointsmanage_page(mobile=None, nickName=None, endTime=None, beginTime=None, headers=None, **kwargs):
    """
    用户积分列表查询-历史接口
    up_time=1676338867

    params: nickName :  : 
    params: mobile :  : 
    params: beginTime :  : 前端日期后面必须要追加 00:00:00
    params: endTime :  : 前端日期后面必须要追加 23:59:59
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : array : 
              total : number : 总数量
              size : number : 页码大小
              current : number : 当前页码
              pages : number : 总页码数
    """
    _method = "GET"
    _url = "/common/userPointsManage/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "nickName": nickName,
        "mobile": mobile,
        "beginTime": beginTime,  # 前端日期后面必须要追加 00:00:00
        "endTime": endTime,  # 前端日期后面必须要追加 23:59:59
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/userPointsManage/manualChangeUserPoints")
def common_userpointsmanage_manualchangeuserpoints(userId=None, operatePoint=None, operateType=None, taskName=None, operateMark=None, pointChangType=None, headers=None, **kwargs):
    """
    用户积分手动调整-历史接口
    up_time=1676338835

    params: userId : number : 用户id
    params: operateType : string : 积分操作类型 目前只有 “增加” 一类
    params: operatePoint : integer : 操作的积分数量
    params: operateMark : string : 操作的积分备注
    params: taskName : string : 任务名称 注册 签到 消费
    params: pointChangType : number : 1--增加  2--消耗
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/common/userPointsManage/manualChangeUserPoints"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
        "operateType": operateType,  # 积分操作类型 目前只有 “增加” 一类
        "operatePoint": operatePoint,  # 操作的积分数量
        "operateMark": operateMark,  # 操作的积分备注
        "taskName": taskName,  # 任务名称 注册 签到 消费
        "pointChangType": pointChangType,  # 1--增加  2--消耗
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/userPointsManage/beforePointsExport")
def common_userpointsmanage_beforepointsexport(logIds=None, endTime=None, mobile=None, nickName=None, beginTime=None, headers=None, **kwargs):
    """
    积分导出前置判断-历史接口
    up_time=1676338890

    params: nickName :  : 用户昵称
    params: mobile :  : 用户手机号
    params: beginTime :  : 注册时间查询范围--开始时间
    params: endTime :  : 注册时间查询范围--结束时间
    params: logIds :  : 积分明细Id，用于积分导出，如果传参表示勾选数据导出
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : boolean : true 调用积分导出方法
    """
    _method = "GET"
    _url = "/common/userPointsManage/beforePointsExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "nickName": nickName,  # 用户昵称
        "mobile": mobile,  # 用户手机号
        "beginTime": beginTime,  # 注册时间查询范围--开始时间
        "endTime": endTime,  # 注册时间查询范围--结束时间
        "logIds": logIds,  # 积分明细Id，用于积分导出，如果传参表示勾选数据导出
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/activityManager/updateActivityTop")
def activitymanager_updateactivitytop(topFlag=None, activityId=None, headers=None, **kwargs):
    """
    后台管理-置顶接口-Y
    up_time=1675649321

    params: activityId : string : 活动主键
    params: topFlag : integer : 活动置顶标识 0-不置顶 1-置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/activityManager/updateActivityTop"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动主键
        "topFlag": topFlag,  # 活动置顶标识 0-不置顶 1-置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/adjustPoints/pageList")
def radarpoints_adjustpoints_pagelist(userId=None, current=None, adjustTimeBefore=None, size=None, adjustNotes=None, mobile=None, adjustTimeEnd=None, nickName=None, optAbility=None, optAbilityName=None, headers=None, **kwargs):
    """
    积分调整 - 分页查询
    up_time=1677209059

    params: userId :  : 用户id
    params: nickName :  : 用户名
    params: mobile :  : 手机号
    params: adjustNotes :  : 调整原因说明
    params: optAbility :  : 调整积分方式
    params: optAbilityName :  : 调整积分方式枚举
    params: adjustTimeBefore :  : 调整时间 - 开始
    params: adjustTimeEnd :  : 调整时间 - 结束
    params: current :  : 页码
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200：成功，其他失败
    params: msg : string : 信息
    params: data : array : 分页数据
              current : number : 页码
              pages : number : 总页数
              size : number : 每页大小
              total : number : 数据总数
              records : array : list
    """
    _method = "GET"
    _url = "/radarpoints/adjustPoints/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
        "nickName": nickName,  # 用户名
        "mobile": mobile,  # 手机号
        "adjustNotes": adjustNotes,  # 调整原因说明
        "optAbility": optAbility,  # 调整积分方式
        "optAbilityName": optAbilityName,  # 调整积分方式枚举
        "adjustTimeBefore": adjustTimeBefore,  # 调整时间 - 开始
        "adjustTimeEnd": adjustTimeEnd,  # 调整时间 - 结束
        "current": current,  # 页码
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/adjustPoints/getUserPointsQtyByUserId")
def radarpoints_adjustpoints_getuserpointsqtybyuserid(userId=None, headers=None, **kwargs):
    """
    积分调整 - 根据UserId查询详情
    up_time=1677458192

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200-成功，其他-失败
    params: msg : string : 提示信息
    params: data : object : 
              userId : string : 用户ID
              mobile : string : 手机号码
              nickName : string : 昵称
              avatarUrl : string : 头像
              physicalQty : integer : 可用积分
              freezeQty : integer : 冻结积分
    """
    _method = "GET"
    _url = "/radarpoints/adjustPoints/getUserPointsQtyByUserId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/adjustPoints/getUserPointsQtyByMobile")
def radarpoints_adjustpoints_getuserpointsqtybymobile(mobile=None, headers=None, **kwargs):
    """
    积分调整 - 根据Mobile查询详情
    up_time=1677206085

    params: mobile :  : 手机号码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200-成功，其他-失败
    params: msg : string : 提示信息
    params: data : object : 
              userId : string : 用户ID
              mobile : string : 手机号码
              nickName : string : 昵称
              avatarUrl : string : 头像地址
              physicalQty : integer : 可用积分
              freezeQty : integer : 冻结积分
    """
    _method = "GET"
    _url = "/radarpoints/adjustPoints/getUserPointsQtyByMobile"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 手机号码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/adjustPoints/export")
def radarpoints_adjustpoints_export(userId=None, current=None, adjustTimeBefore=None, size=None, adjustNotes=None, mobile=None, adjustTimeEnd=None, nickName=None, optAbility=None, optAbilityName=None, headers=None, **kwargs):
    """
    积分调整 - 导出excel
    up_time=1677216479

    params: userId :  : 用户id
    params: nickName :  : 用户名
    params: mobile :  : 手机号
    params: adjustNotes :  : 调整原因说明
    params: optAbility :  : 调整积分方式
    params: optAbilityName :  : 调整积分方式枚举
    params: adjustTimeBefore :  : 调整时间 - 开始
    params: adjustTimeEnd :  : 调整时间 - 结束
    params: current :  : 页码
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/radarpoints/adjustPoints/export"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
        "nickName": nickName,  # 用户名
        "mobile": mobile,  # 手机号
        "adjustNotes": adjustNotes,  # 调整原因说明
        "optAbility": optAbility,  # 调整积分方式
        "optAbilityName": optAbilityName,  # 调整积分方式枚举
        "adjustTimeBefore": adjustTimeBefore,  # 调整时间 - 开始
        "adjustTimeEnd": adjustTimeEnd,  # 调整时间 - 结束
        "current": current,  # 页码
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_subjectweb import AssertsContentSubjectweb
from service.app_a.apis.content import apis_content_subjectweb


class FunsContentSubjectweb(AssertsContentSubjectweb):
    @allure.step(title="专题-后台官网专题文章列表-Y")
    def content_subjectweb_detailessay(self, subjectId="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/subjectweb/detailEssay
                params: current :  : 当前页
                params: size :  : 当前条数
                params: subjectId :  : 专题主键id
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_detailessay(**_kwargs)

        self.assert_content_subjectweb_detailessay(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网专题新增-Y")
    def content_subjectweb_add(self, siftPicUrl="$None$", siftFlag="$None$", level="$None$", parentId="$None$", subPicUrl="$None$", isService="$None$", explain="$None$", recommend="$None$", isSearch="$None$", web="$None$", subjectRank="$None$", subjectName="$None$", serial="$None$", status="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subjectweb/add
                params: subjectName : string : 专题名称
                params: level : string : 专题等级
                params: status : string : 是否可用1：是 0：否
                params: explain : string : 说明
                params: type : string : 关联类型
                params: subPicUrl : string : 专题图片
                params: parentId : string : 父级专题主键
                params: serial : integer : 序号
                params: siftFlag : integer : 精选标识 0否 1是
                params: isService : integer : 是否有客服入口 0否 1是
                params: isSearch : integer : 是否配置搜索 0否 1是
                params: siftPicUrl : string : 精选配图
                params: web : string :
                params: recommend : integer : 咨询页展示
                params: subjectRank : integer : 精选权重
                params: headers : 请求头
        """
        siftPicUrl = self.get_value_choice(siftPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        siftFlag = self.get_value_choice(siftFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        level = self.get_value_choice(level, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subPicUrl = self.get_value_choice(subPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isService = self.get_value_choice(isService, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        explain = self.get_value_choice(explain, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        recommend = self.get_value_choice(recommend, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isSearch = self.get_value_choice(isSearch, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        web = self.get_value_choice(web, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subjectRank = self.get_value_choice(subjectRank, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subjectName = self.get_value_choice(subjectName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        serial = self.get_value_choice(serial, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_add(**_kwargs)

        self.assert_content_subjectweb_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网专题类型列表-Y")
    def content_subjectweb_treelist(self, _assert=True,  **kwargs):
        """
            url=/content/subjectweb/treeList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_treelist(**_kwargs)

        self.assert_content_subjectweb_treelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网保存/更新-Y")
    def content_subjectweb_save(self, subjectId="$None$", siftFlag="$None$", delFlag="$None$", parentId="$None$", subPicUrl="$None$", isService="$None$", explain="$None$", isSearch="$None$", subjectName="$None$", status="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subjectweb/save
                params: subjectId : string :
                params: subjectName : string :
                params: delFlag : string :
                params: subPicUrl : string :
                params: explain : string :
                params: status : string :
                params: type : string :
                params: parentId : string :
                params: siftFlag : string :
                params: isService : string :
                params: isSearch : string :
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        siftFlag = self.get_value_choice(siftFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        delFlag = self.get_value_choice(delFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subPicUrl = self.get_value_choice(subPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isService = self.get_value_choice(isService, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        explain = self.get_value_choice(explain, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isSearch = self.get_value_choice(isSearch, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subjectName = self.get_value_choice(subjectName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_save(**_kwargs)

        self.assert_content_subjectweb_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网删除专题-Y")
    def content_subjectweb_del(self, subjectId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subjectweb/del
                params: subjectId : string : 专题主键
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_del(**_kwargs)

        self.assert_content_subjectweb_del(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网查询专题详情-Y")
    def content_subjectweb_detail(self, subjectId="$None$", _assert=True,  **kwargs):
        """
            url=/content/subjectweb/detail
                params: subjectId :  :
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_detail(**_kwargs)

        self.assert_content_subjectweb_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="新闻中心文章列表-Y")
    def content_subjectweb_detailessaynew(self, subjectId="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/subjectweb/detailEssayNew
                params: current :  :
                params: size :  :
                params: subjectId :  : 2 官方新闻 3 自媒体 4 媒体报道  null 全部
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subjectweb.content_subjectweb_detailessaynew(**_kwargs)

        self.assert_content_subjectweb_detailessaynew(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/topic4C/del")
def content_topic4c_del(topicId=None, headers=None, **kwargs):
    """
    话题-删除话题
    up_time=1675133827

    params: topicId : string : 话题主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/topic4C/del"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "topicId": topicId,  # 话题主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/topic4C/getContentList")
def content_topic4c_getcontentlist(topicId=None, size=None, current=None, headers=None, **kwargs):
    """
    话题-获取动态关联列表-Y
    up_time=1675653387

    params: topicId :  : 话题主键
    params: size :  : 每页数据数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : array : 
              contentId : string : 内容主键
              topFlag : number : 是否置顶
              createTime : string : 创建时间
              createName : string : 发布人
              userType : number : 用户类型1：潜在客户2：内部用户3：虚拟用户4：保有客户
              mobile : string : 手机号
              topicTitle : string : 话题标题
              contentDesc : string : 动态内容
              contentImg : string : 动态图片
              contentStatus : number : 动态状态
    """
    _method = "GET"
    _url = "/content/topic4C/getContentList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "topicId": topicId,  # 话题主键
        "size": size,  # 每页数据数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/topic4C/list")
def content_topic4c_list(size=None, keyWord=None, topicId=None, endTime=None, createBy=None, startTime=None, current=None, headers=None, **kwargs):
    """
    话题-搜索话题列表
    up_time=1675133829

    params: topicId :  : 话题主键
    params: createBy :  : 发布人主键
    params: keyWord :  : 话题关键字
    params: startTime :  : 搜索开始时间
    params: endTime :  : 搜索结束时间
    params: size :  : 每页数量数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : array : 
              topicId : string : 话题主键
              topFlag : number : 是否置顶1：是0：否
              createTime : string : 创建时间
              publishTime : string : 发布时间
              createName : string : 发布人
              avatarUrl : string : 发布人头像
              topicType : number : 1:动态（目前只有动态）
              userType : number : 发布人类型1：潜在客户2：内部用户3：虚拟用户4：保有客户
              mobile : string : 手机号
              topicTitle : string : 话题标题
              contentCount : number : 动态关联数量
              topicContent : string : 话题内容，描述
    """
    _method = "GET"
    _url = "/content/topic4C/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "topicId": topicId,  # 话题主键
        "createBy": createBy,  # 发布人主键
        "keyWord": keyWord,  # 话题关键字
        "startTime": startTime,  # 搜索开始时间
        "endTime": endTime,  # 搜索结束时间
        "size": size,  # 每页数量数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/topic4C/insert")
def content_topic4c_insert(topicTitle=None, topicId=None, author=None, headers=None, **kwargs):
    """
    话题-新增话题
    up_time=1675133829

    params: topicId : string : 话题主键
    params: topicTitle : string : 话题
    params: author : number : 话题作者
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/topic4C/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "topicId": topicId,  # 话题主键
        "topicTitle": topicTitle,  # 话题
        "author": author,  # 话题作者
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/topic4C/top")
def content_topic4c_top(topicId=None, type=None, headers=None, **kwargs):
    """
    话题-置顶
    up_time=1675133829

    params: topicId : string : 话题主键
    params: type : string : 操作类型1：置顶2：取消置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/topic4C/top"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "topicId": topicId,  # 话题主键
        "type": type,  # 操作类型1：置顶2：取消置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/agreement/getAgreement")
def content_agreement_getagreement( headers=None, **kwargs):
    """
    查询创建活动所需协议
    up_time=1678259215

    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : array : 
              agreementId : string : 协议id
              code : string : 协议编码
              name : string : 协议名称
              content : string : 协议正文
              updateTime : string : data更新时间
              updateBy : number : 更新人
              updateByName : string : 更新人名称
              status : integer : 1.生效 2.过期
              version : string : 版本号
              createTime : string : data发布日期
              enableTime : string : data生效日期
    """
    _method = "GET"
    _url = "/content/agreement/getAgreement"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/getByCode")
def content_agreement_getbycode(agreementCode=None, headers=None, **kwargs):
    """
    协议-C端用户根据编码查询协议-Y
    up_time=1675217511

    params: agreementCode :  : PRIVACYPOLICY:隐私协议，USERPOLICY：用户协议， THIRDPARTYSDKPOLICY：第三方sdk目录，POINTRULE：积分规则，SIGININRULE：签到规则
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              agreementId : string : 协议id
              code : string : 协议编码
              name : string : 协议名称
              content : string : 协议内容
              updateTime : string : 修改时间
              updateBy : string : 修改人
              updateByName : string : 修改人姓名
              status : number : 状态
              version : string : 协议版本
              createTime : string : 创建实际
              enableTime : string : 启用时间
    """
    _method = "GET"
    _url = "/content/agreement/getByCode"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "agreementCode": agreementCode,  # PRIVACYPOLICY:隐私协议，USERPOLICY：用户协议， THIRDPARTYSDKPOLICY：第三方sdk目录，POINTRULE：积分规则，SIGININRULE：签到规则
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/getAgreementByCode")
def content_agreement_getagreementbycode(agreementCode=None, headers=None, **kwargs):
    """
    协议-h5查询协议-Y
    up_time=1675680320

    params: agreementCode :  : 协议编码 
隐私协议:PRIVACYPOLICY、
用户协议:USERPOLICY、
权限清单:PERMISSIONSLIST、
第三方SDK列表:THIRDPARTYSDKPOLICY、
用户注销: USERDESTROY
车机服务协议: CARSERVICE
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              agreementId : string : 协议主键
              code : string : 协议编码
              name : string : 协议名称
              content : string : 协议内容
              updateTime : string : 更新时间
              updateBy : string : 更新人
              updateByName : null : 更新人名称
              status : number : 
              version : string : 1.生效 2.过期
              createTime : null : 创建日期
              enableTime : null : 生效日期
    """
    _method = "GET"
    _url = "/content/agreement/getAgreementByCode"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "agreementCode": agreementCode,  # 协议编码  隐私协议:PRIVACYPOLICY、 用户协议:USERPOLICY、 权限清单:PERMISSIONSLIST、 第三方SDK列表:THIRDPARTYSDKPOLICY、 用户注销: USERDESTROY 车机服务协议: CARSERVICE
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/updateStatus")
def content_agreement_updatestatus(code=None, agreementId=None, status=None, headers=None, **kwargs):
    """
    协议-停用启用协议-Y
    up_time=1675680241

    params: agreementId : text : 
    params: status : text : 状态 1 启用 2 停用
    params: code : text : 协议编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/agreement/updateStatus"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "agreementId": agreementId,
        "status": status,  # 状态 1 启用 2 停用
        "code": code,  # 协议编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/list")
def content_agreement_list(size=None, current=None, headers=None, **kwargs):
    """
    协议-协议列表-Y
    up_time=1678246318

    params: size :  : 每页数据数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              agreementId : string : 协议id
              name : string : 协议名称
              code : string : 协议编码
              content : string : 协议内容
              updateTime : string : 更新时间
              updateBy : string : 更新人id
              updateByName : string : 更新人名称
              status : number : 1.生效 2.过期
              version : string : 版本号
              createTime : string : 发布时间
              enableTime : string : 生效时间
    """
    _method = "GET"
    _url = "/content/agreement/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "size": size,  # 每页数据数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/save")
def content_agreement_save(code=None, content=None, name=None, version=None, headers=None, **kwargs):
    """
    协议-新增协议-Y
    up_time=1675675877

    params: name : string : 协议名
    params: content : string : 内容
    params: version : number : 版本号
    params: code : string : 协议编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/agreement/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "name": name,  # 协议名
        "content": content,  # 内容
        "version": version,  # 版本号
        "code": code,  # 协议编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/update")
def content_agreement_update(code=None, name=None, agreementId=None, version=None, content=None, headers=None, **kwargs):
    """
    协议-更新协议-Y
    up_time=1675680222

    params: name : string : 协议名
    params: content : string : 内容
    params: version : number : 版本号
    params: agreementId : string : 协议id
    params: code : string : 协议编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/agreement/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "name": name,  # 协议名
        "content": content,  # 内容
        "version": version,  # 版本号
        "agreementId": agreementId,  # 协议id
        "code": code,  # 协议编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/agreement/getById")
def content_agreement_getbyid(agreementId=None, headers=None, **kwargs):
    """
    协议-根据id获取详情-Y
    up_time=1675680268

    params: agreementId :  : 协议主键1-隐私协议2-用户协议3-第三方SDK目录
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              agreementId : number : 协议主键
              name : string : 协议名称
              code : string : 协议编码
              content : string : 协议内容
    """
    _method = "GET"
    _url = "/content/agreement/getById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "agreementId": agreementId,  # 协议主键1-隐私协议2-用户协议3-第三方SDK目录
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/subjectweb/detailEssay")
def content_subjectweb_detailessay(subjectId=None, size=None, current=None, headers=None, **kwargs):
    """
    专题-后台官网专题文章列表-Y
    up_time=1675754018

    params: current :  : 当前页
    params: size :  : 当前条数
    params: subjectId :  : 专题主键id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 返回待发布的文章列表
              total : number : 总页数
              size : number : 每页大小
              current : number : 当前页
    """
    _method = "GET"
    _url = "/content/subjectweb/detailEssay"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 当前页
        "size": size,  # 当前条数
        "subjectId": subjectId,  # 专题主键id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/add")
def content_subjectweb_add(siftPicUrl=None, siftFlag=None, level=None, parentId=None, subPicUrl=None, isService=None, explain=None, recommend=None, isSearch=None, web=None, subjectRank=None, subjectName=None, serial=None, status=None, type=None, headers=None, **kwargs):
    """
    专题-后台官网专题新增-Y
    up_time=1675754357

    params: subjectName : string : 专题名称
    params: level : string : 专题等级
    params: status : string : 是否可用1：是 0：否
    params: explain : string : 说明
    params: type : string : 关联类型
    params: subPicUrl : string : 专题图片
    params: parentId : string : 父级专题主键
    params: serial : integer : 序号
    params: siftFlag : integer : 精选标识 0否 1是
    params: isService : integer : 是否有客服入口 0否 1是
    params: isSearch : integer : 是否配置搜索 0否 1是
    params: siftPicUrl : string : 精选配图
    params: web : string : 
    params: recommend : integer : 咨询页展示
    params: subjectRank : integer : 精选权重
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subjectweb/add"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectName": subjectName,  # 专题名称
        "level": level,  # 专题等级
        "status": status,  # 是否可用1：是 0：否
        "explain": explain,  # 说明
        "type": type,  # 关联类型
        "subPicUrl": subPicUrl,  # 专题图片
        "parentId": parentId,  # 父级专题主键
        "serial": serial,  # 序号
        "siftFlag": siftFlag,  # 精选标识 0否 1是
        "isService": isService,  # 是否有客服入口 0否 1是
        "isSearch": isSearch,  # 是否配置搜索 0否 1是
        "siftPicUrl": siftPicUrl,  # 精选配图
        "web": web,
        "recommend": recommend,  # 咨询页展示
        "subjectRank": subjectRank,  # 精选权重
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/treeList")
def content_subjectweb_treelist( headers=None, **kwargs):
    """
    专题-后台官网专题类型列表-Y
    up_time=1675756064

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              sub : array : 类目类型下的二级专题
              essList : array : 文章专题下的资讯分页
              childSubList : array : 类目类型下的二级专题
              jxJudge : number : 用于判定精选框 是否可以多选
    """
    _method = "GET"
    _url = "/content/subjectweb/treeList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/save")
def content_subjectweb_save(subjectId=None, siftFlag=None, delFlag=None, parentId=None, subPicUrl=None, isService=None, explain=None, isSearch=None, subjectName=None, status=None, type=None, headers=None, **kwargs):
    """
    专题-后台官网保存/更新-Y
    up_time=1675754842

    params: subjectId : string : 
    params: subjectName : string : 
    params: delFlag : string : 
    params: subPicUrl : string : 
    params: explain : string : 
    params: status : string : 
    params: type : string : 
    params: parentId : string : 
    params: siftFlag : string : 
    params: isService : string : 
    params: isSearch : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subjectweb/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,
        "subjectName": subjectName,
        "delFlag": delFlag,
        "subPicUrl": subPicUrl,
        "explain": explain,
        "status": status,
        "type": type,
        "parentId": parentId,
        "siftFlag": siftFlag,
        "isService": isService,
        "isSearch": isSearch,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/del")
def content_subjectweb_del(subjectId=None, headers=None, **kwargs):
    """
    专题-后台官网删除专题-Y
    up_time=1675751503

    params: subjectId : string : 专题主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subjectweb/del"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,  # 专题主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/detail")
def content_subjectweb_detail(subjectId=None, headers=None, **kwargs):
    """
    专题-后台官网查询专题详情-Y
    up_time=1675751256

    params: subjectId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 已发布的文章列表
              subjectId : string : 专题主键
              subjectName : string : 专题名称
              level : number : 专题等级
              explain : string : 说明
              status : number : 是否可用：0.否1：是
              subPicUrl : null : 专题图片
              type : number : 专题类型1.类目专题 2.文章专题
              createTime : string : 创建时间
              userName : null : 维护人姓名
    """
    _method = "GET"
    _url = "/content/subjectweb/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subjectweb/detailEssayNew")
def content_subjectweb_detailessaynew(subjectId=None, size=None, current=None, headers=None, **kwargs):
    """
    新闻中心文章列表-Y
    up_time=1675753591

    params: current :  : 
    params: size :  : 
    params: subjectId :  : 2 官方新闻 3 自媒体 4 媒体报道  null 全部
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 总页数
              size : number : 每页大小
              curren : number : 当前页
    """
    _method = "GET"
    _url = "/content/subjectweb/detailEssayNew"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "subjectId": subjectId,  # 2 官方新闻 3 自媒体 4 媒体报道  null 全部
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from service.app_a.funs.open.haohan.funs_open_haohan_rights import FunsOpenHaohanRights
from service.app_a.funs.open.haohan.funs_open_haohan_relation import FunsOpenHaohanRelation


class FunsOpenHaohan(FunsOpenHaohanRights, FunsOpenHaohanRelation):
    pass




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/subject/detailEssay")
def content_subject_detailessay(subjectId=None, size=None, subjectName=None, current=None, headers=None, **kwargs):
    """
    专题-后台App专题文章列表-Y
    up_time=1675752193

    params: current :  : 
    params: size :  : 
    params: subjectId :  : Long
    params: subjectName :  :  string
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 总页数
              size : number : 每页大小
              current : number : 当前页
    """
    _method = "GET"
    _url = "/content/subject/detailEssay"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "subjectId": subjectId,  # Long
        "subjectName": subjectName,  #  string
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/add")
def content_subject_add(level=None, parentId=None, subPicUrl=None, explain=None, subjectName=None, status=None, type=None, headers=None, **kwargs):
    """
    专题-后台App专题新增-Y
    up_time=1675749730

    params: subjectName : string : 专题名称
    params: parentId : string : 父级专题主键
    params: level : number : 专题等级
    params: status : number : 是否可用1：是0：否
    params: explain : string : 说明
    params: type : number : 关联类型
    params: subPicUrl : string : 专题图片
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subject/add"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectName": subjectName,  # 专题名称
        "parentId": parentId,  # 父级专题主键
        "level": level,  # 专题等级
        "status": status,  # 是否可用1：是0：否
        "explain": explain,  # 说明
        "type": type,  # 关联类型
        "subPicUrl": subPicUrl,  # 专题图片
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/del")
def content_subject_del(subjectId=None, headers=None, **kwargs):
    """
    专题-后台App删除专题-Y
    up_time=1675749831

    params: subjectId : text : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subject/del"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/mobileSubject")
def content_subject_mobilesubject(subjectId=None, serial=None, parentId=None, headers=None, **kwargs):
    """
    专题-后台App移动专题更新-Y
    up_time=1675750974

    params: subjectId : text : 移动的专题ID
    params: parentId : text : 移动到的一级专题ID
    params: serial : text : 排序
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : boolean : true成功
    """
    _method = "POST"
    _url = "/content/subject/mobileSubject"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,  # 移动的专题ID
        "parentId": parentId,  # 移动到的一级专题ID
        "serial": serial,  # 排序
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/getEssaySubjects")
def content_subject_getessaysubjects( headers=None, **kwargs):
    """
    文章-发布到下拉数据-Y
    up_time=1675750961

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              subjectId : string : 专题编码
              subjectName : string : 专题名称
              level : number : 级别
              parentId : ['string', 'null'] : 上级专题编码
              explain : null : 
              status : number : 
              subPicUrl : ['string', 'null'] : 
              type : number : 
              serial : number : 
              createTime : string : 
              createBy : null : 
              updateTime : string : 
              updateBy : null : 
              delFlag : number : 
    """
    _method = "GET"
    _url = "/content/subject/getEssaySubjects"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/detail")
def content_subject_detail(subjectId=None, headers=None, **kwargs):
    """
    专题-后台App查询专题详情-Y
    up_time=1675752083

    params: subjectId :  : 广告位主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              subjectId : number : 专题主键
              subjectName : string : 专题名称
              level : number : 专题等级
              parentId : number : 上级主题ID
              serial : integer : 序号
              createTime : string : 创建时间
              createBy : number : 创建人
              updateTime : string : 更新时间
              updateBy : number : 更新人
              delFlag : integer : 标记：0.正常 1.删除
              subPicUrl : string : 专题图片
              essayList : array : 文章列表
              type : number : 专题类型1.类目专题 2.文章专题
              userName : string : 维护人姓名
    """
    _method = "GET"
    _url = "/content/subject/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,  # 广告位主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/treeList")
def content_subject_treelist( headers=None, **kwargs):
    """
    专题-后台APP专题类型列表-Y
    up_time=1675749366

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : array : 
    """
    _method = "GET"
    _url = "/content/subject/treeList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/subject/save")
def content_subject_save(subjectId=None, siftFlag=None, delFlag=None, level=None, parentId=None, subPicUrl=None, isService=None, explain=None, isSearch=None, subjectName=None, status=None, type=None, headers=None, **kwargs):
    """
    专题-后台App保存/更新-Y
    up_time=1675749773

    params: subjectId : number : 
    params: subjectName : string : 
    params: level : number : 
    params: delFlag : number : 
    params: subPicUrl : string : 
    params: explain : string : 
    params: status : number : 
    params: type : number : 
    params: parentId : string : 父ID
    params: siftFlag : number : 是否精选 1是 0否
    params: isService : number : 是否设置客服入口 1是 0否
    params: isSearch : number : 是否配置搜索 0否 1是
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/subject/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "subjectId": subjectId,
        "subjectName": subjectName,
        "level": level,
        "delFlag": delFlag,
        "subPicUrl": subPicUrl,
        "explain": explain,
        "status": status,
        "type": type,
        "parentId": parentId,  # 父ID
        "siftFlag": siftFlag,  # 是否精选 1是 0否
        "isService": isService,  # 是否设置客服入口 1是 0否
        "isSearch": isSearch,  # 是否配置搜索 0否 1是
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/rightsOrder/receive/update")
def order_rightsorder_receive_update(rightsId=None, rightsName=None, rightsType=None, userId=None, refundDate=None, createTime=None, receiveDate=None, refundBillNo=None, updateId=None, payBillNo=None, payDate=None, mobile=None, payAmount=None, createBy=None, rightsOrderId=None, updateTime=None, orderMainId=None, useStatus=None, headers=None, **kwargs):
    """
    权益-编辑权益订单-Y
    up_time=1675660709

    params: rightsOrderId : string : 
    params: rightsId : string : 
    params: rightsType : string : 
    params: rightsName : string : 
    params: orderMainId : string : 
    params: userId : string : 
    params: mobile : string : 
    params: payAmount : string : 
    params: useStatus : string : 
    params: receiveDate : string : 
    params: payDate : string : 
    params: refundDate : string : 
    params: payBillNo : string : 
    params: refundBillNo : string : 
    params: createTime : string : 
    params: createBy : string : 
    params: updateTime : string : 
    params: updateId : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败 1成功
    params: msg : string : 
    params: field_203 : string : 
    """
    _method = "POST"
    _url = "/order/rightsOrder/receive/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsOrderId": rightsOrderId,
        "rightsId": rightsId,
        "rightsType": rightsType,
        "rightsName": rightsName,
        "orderMainId": orderMainId,
        "userId": userId,
        "mobile": mobile,
        "payAmount": payAmount,
        "useStatus": useStatus,
        "receiveDate": receiveDate,
        "payDate": payDate,
        "refundDate": refundDate,
        "payBillNo": payBillNo,
        "refundBillNo": refundBillNo,
        "createTime": createTime,
        "createBy": createBy,
        "updateTime": updateTime,
        "updateId": updateId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/remoteinterfacelog/getLogPage")
def common_remoteinterfacelog_getlogpage(size=None, userName=None, endTime=None, interfaceType=None, mobile=None, startTime=None, current=None, headers=None, **kwargs):
    """
    查询三方日志接口-Y
    up_time=1675324564

    params: interfaceType :  : 日志类型（1.支付日志  2.退款日志  3.换电日志）
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: userName :  : 用户昵称
    params: mobile :  : 手机号
    params: size :  : 每页条数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : number : 
              maxLimit : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/common/remoteinterfacelog/getLogPage"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "interfaceType": interfaceType,  # 日志类型（1.支付日志  2.退款日志  3.换电日志）
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "userName": userName,  # 用户昵称
        "mobile": mobile,  # 手机号
        "size": size,  # 每页条数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.goods.asserts_goods_area import AssertsGoodsArea
from service.app_a.apis.goods import apis_goods_area


class FunsGoodsArea(AssertsGoodsArea):
    @allure.step(title="订单管理-地区下拉（930版本）-Y")
    def goods_area_getparentarea(self, country="$None$", parentId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/area/getParentArea
                params: parentId :  : 父地区id（null 则省，下一级递增）
                params: country :  : all会加上全国信息
                params: headers : 请求头
        """
        country = self.get_list_choice(country, list_or_dict=None, key="country")
        parentId = self.get_list_choice(parentId, list_or_dict=None, key="parentId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getparentarea(**_kwargs)

        self.assert_goods_area_getparentarea(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="pc端查询城市默认经销商-Y")
    def goods_area_getdefaultdealer(self, cityCode="$None$", _assert=True,  **kwargs):
        """
            url=/goods/area/getDefaultDealer
                params: cityCode :  : 城市编码
                params: headers : 请求头
        """
        cityCode = self.get_list_choice(cityCode, list_or_dict=None, key="cityCode")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getdefaultdealer(**_kwargs)

        self.assert_goods_area_getdefaultdealer(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-设置默认经销商-Y")
    def goods_area_insertrelation(self, areaIds="$None$", dealerCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/goods/area/insertRelation
                params: areaIds : array : 地区集合
                type : integer : None
                description : 地区Id : None
                params: dealerCode : string : 进销商编码
                params: headers : 请求头
        """
        areaIds = self.get_value_choice(areaIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        dealerCode = self.get_value_choice(dealerCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_insertrelation(**_kwargs)

        self.assert_goods_area_insertrelation(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="城市禁行列表查询-Y")
    def goods_area_getcitylist(self, size=10, cType="$None$", cName="$None$", pName="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/goods/area/getCityList
                params: size :  : 当前页数量
                params: current :  : 当前页号
                params: pName :  : 省份名称
                params: cName :  : 城市名称
                params: cType :  : 城市禁行类型 0:全面解禁，1:部分解禁，2:禁行
                params: headers : 请求头
        """
        cType = self.get_list_choice(cType, list_or_dict=None, key="cType")
        cName = self.get_list_choice(cName, list_or_dict=None, key="cName")
        pName = self.get_list_choice(pName, list_or_dict=None, key="pName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getcitylist(**_kwargs)

        self.assert_goods_area_getcitylist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="查询禁行城市信息-Y")
    def goods_area_getcitybyid(self, cityId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/area/getCityById
                params: cityId :  : 城市编码
                params: headers : 请求头
        """
        cityId = self.get_list_choice(cityId, list_or_dict=None, key="cityId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getcitybyid(**_kwargs)

        self.assert_goods_area_getcitybyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="地区下拉待字母（930）-?")
    def goods_area_getmaparea(self, parentId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/area/getMapArea
                params: parentId :  : 地区Id（省传null ，其余传areaId的值）
                params: headers : 请求头
        """
        parentId = self.get_list_choice(parentId, list_or_dict=None, key="parentId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getmaparea(**_kwargs)

        self.assert_goods_area_getmaparea(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="城市下拉带字母（930）-？")
    def goods_area_getcity(self, parentId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/area/getCity
                params: parentId :  : 父级ID
                params: headers : 请求头
        """
        parentId = self.get_list_choice(parentId, list_or_dict=None, key="parentId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_getcity(**_kwargs)

        self.assert_goods_area_getcity(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="城市禁行状态变更-？")
    def goods_area_updatecitytype(self, cId="$None$", cType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/goods/area/updateCityType
                params: cType : integer : 禁用类型
                params: cId : integer : 城市编码
                params: headers : 请求头
        """
        cId = self.get_value_choice(cId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        cType = self.get_value_choice(cType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_area.goods_area_updatecitytype(**_kwargs)

        self.assert_goods_area_updatecitytype(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.funs.funs_app_a import FunsAppA


@allure.epic("接口测试")
@allure.feature("场景：接口（/page）")
class TestPage:
    def setup(self):
        self.f = FunsAppA()

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商")
    def test_page_001(self):
        self.f.page()

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__翻页")
    def test_page__current_002(self):
        self.f.page(current=2)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__每页条数")
    def test_page__size_003(self):
        self.f.page(size=20)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： shopBusinessType")
    def test_page__shopBusinessType_004(self):
        self.f.page(shopBusinessType=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： city")
    def test_page__city_005(self):
        self.f.page(city=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： cityNameSort")
    def test_page__cityNameSort_006(self):
        self.f.page(cityNameSort=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： provinceNameSort")
    def test_page__provinceNameSort_007(self):
        self.f.page(provinceNameSort=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： province")
    def test_page__province_008(self):
        self.f.page(province=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： districtNameSort")
    def test_page__districtNameSort_009(self):
        self.f.page(districtNameSort=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： dealerCode")
    def test_page__dealerCode_010(self):
        self.f.page(dealerCode=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： dealerAddress")
    def test_page__dealerAddress_011(self):
        self.f.page(dealerAddress=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： dealerName")
    def test_page__dealerName_012(self):
        self.f.page(dealerName=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__单参数有值： district")
    def test_page__district_013(self):
        self.f.page(district=True)

    # @pytest.mark.skip("不执行")
    @allure.step(title="网点列表-获取经销商__所有参数有值")
    def test_page__all_014(self):
        self.f.page(shopBusinessType=True, city=True, cityNameSort=True, provinceNameSort=True, province=True, districtNameSort=True, dealerCode=True, dealerAddress=True, dealerName=True, district=True)




import allure

from service.app_a import unit_request
from service.app_a.sqls.goods.sqls_goods_area import SqlsGoodsArea


class AssertsGoodsArea(SqlsGoodsArea):
    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getparentarea(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getparentarea(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["country", "parentId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getdefaultdealer(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getdefaultdealer(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cityCode"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_insertrelation(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_insertrelation(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["areaIds", "dealerCode"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getcitylist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getcitylist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cType", "cName", "pName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getcitybyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getcitybyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getmaparea(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getmaparea(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["parentId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_getcity(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_getcity(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["parentId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_area_updatecitytype(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_area_updatecitytype(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["cId", "cType"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_essayweb import AssertsContentEssayweb
from service.app_a.apis.content import apis_content_essayweb


class FunsContentEssayweb(AssertsContentEssayweb):
    @allure.step(title="专题-后台官网专题新建文章-Y")
    def content_essayweb_add(self, publishChannel="$None$", essPicUrl="$None$", publishType="$None$", author="$None$", essayId="$None$", title="$None$", content="$None$", status="$None$", publishTime="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essayweb/add
                params: essayId : string : 文章主键
                params: title : string : 文章标题
                params: author : string : 作者
                params: publishType : string : 发布类型1：立即发布2：定时发布
                params: publishTime : string : 定时发布时间
                params: essPicUrl : string : 文章封面
                params: publishChannel : string : 发布渠道
                params: content : string : 文章正文富文本
                params: status : string : 保存时传1，提交审核时传2
                params: headers : 请求头
        """
        publishChannel = self.get_value_choice(publishChannel, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essPicUrl = self.get_value_choice(essPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishType = self.get_value_choice(publishType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        author = self.get_value_choice(author, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishTime = self.get_value_choice(publishTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essayweb.content_essayweb_add(**_kwargs)

        self.assert_content_essayweb_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网文章关键词搜索-Y")
    def content_essayweb_searchbykey(self, key="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/essayweb/searchByKey
                params: current :  : 当前页
                params: size :  : 每页条数
                params: key :  : 关键词
                params: headers : 请求头
        """
        key = self.get_list_choice(key, list_or_dict=None, key="key")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essayweb.content_essayweb_searchbykey(**_kwargs)

        self.assert_content_essayweb_searchbykey(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台官网文章删除-Y")
    def content_essayweb_delete_(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essayweb/delete/{essayId}
                params: essayId :  : 文章id
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essayweb.content_essayweb_delete_(**_kwargs)

        self.assert_content_essayweb_delete_(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="新闻中心查看文章详情-Y")
    def content_essayweb_getbyid(self, subjectId="$None$", essayId="$None$", _assert=True,  **kwargs):
        """
            url=/content/essayweb/getById
                params: essayId :  : 文章主键
                params: subjectId :  :
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essayweb.content_essayweb_getbyid(**_kwargs)

        self.assert_content_essayweb_getbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


